# Changelog

## 0.1.1 (5 Jan 2026)

* Added support for system packages that publish a binary module, but not .dist-info package metadata (such as `KStatusNotifierItem`).

## 0.1.0 (16 Dec 2025)

Initial release.
